import os
import inspect
import json
import icon
import pkexec

server = None
cert = None
keep_passwd = False
elevate = None
TRAY_ICON = os.path.dirname(inspect.getfile(icon)) + '/lockWithe.png'
TRAY_ICON_OK = os.path.dirname(inspect.getfile(icon)) + '/lockGreen.png'
TRAY_ICON_ERROR = os.path.dirname(inspect.getfile(icon)) + '/lockRed.png'
POST_UP = os.path.dirname(inspect.getfile(pkexec)) + '/post-up.policy'
UP = os.path.dirname(inspect.getfile(pkexec)) + '/up.policy'
POST_DOWN = os.path.dirname(inspect.getfile(pkexec)) + '/post-down.policy'
DOWN = os.path.dirname(inspect.getfile(pkexec)) + '/down.policy'
USER_POST_UP = None
USER_POST_DOWN = None


def init():
    with open(os.environ["HOME"] + "/.config/snxtray.json") as json_file:
        data = json.load(json_file)
        globals()["server"] = data["server"]
        globals()["cert"] = data["cert"]
        if "keep_passwd" in data.keys():
            globals()["keep_passwd"] = data["keep_passwd"]
        if "elevate" in data.keys():
            globals()["elevate"] = data["elevate"]
        if "post-up" in data.keys():
            globals()["USER_POST_UP"] = data["post-up"]
        if "post-down" in data.keys():
            globals()["USER_POST_DOWN"] = data["post-down"]



#!/usr/bin/env python3
from setuptools import setup
from setuptools import find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()


setup(
    name='snxtray',
    version='0.0.5',
    scripts=['snxtray'],
    install_requires=['psutil==5.7.0', 'wxPython'],
    packages=find_packages(),
    url='https://gitlab.com/linalinn/snxtray',
    license='Mozilla Public License Version 2.0',
    author='LinaLinn',
    author_email='lina.cloud@outlook.de',
    description='Systray for snx',
    long_description=long_description,
    long_description_content_type='text/markdown',
    include_package_data=True,
    data_files=[('icon', ['icon/lockWithe.png', 'icon/lockGreen.png', 'icon/lockRed.png']),
                ('pkexec',['pkexec/up.policy','pkexec/down.policy','pkexec/post-up.policy','pkexec/post-down.policy'])],
    zip_safe=False,
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)',
        'Operating System :: POSIX :: Linux',
    ],
    python_requires='>=3'

)